@@ -5,6 +5,7 @@ from sys import hexversion
 import random
 from .context import sortedcontainers
 from sortedcontainers import SortedList, SortedKeyList
+from itertools import chain, repeat
 import pytest
 
 if hexversion < 0x03000000:
@@ -107,6 +108,16 @@ def test_update():
     assert len(slt) == 11000
     slt._check()
 
+def test_update_order_consistency():
+    setup = [10, 20, 30]
+    slt1 = SortedKeyList(setup, key=modulo)
+    slt2 = SortedKeyList(setup, key=modulo)
+    addition = [40, 50, 60]
+    for value in addition:
+        slt1.add(value)
+    slt2.update(addition)
+    assert slt1 == slt2
+
 def test_contains():
     slt = SortedKeyList(key=modulo)
     slt._reset(7)
